;;********************************************************************
;;********************************************************************
;;  DELSIG8.asm
;;
;;  Assembler source for the 8 bit Deleta Sigma A/D converter.
;;
;;  Rev B, 2002 JUL 25
;;
;;  Copyright: Cypress MicroSystems 2000-2002.  All Rights Reserved.
;;
;;*********************************************************************
;;*********************************************************************

export  DELSIG8_1_Start
export _DELSIG8_1_Start
export  DELSIG8_1_SetPower
export _DELSIG8_1_SetPower
export  DELSIG8_1_Stop
export _DELSIG8_1_Stop
export  DELSIG8_1_StartAD
export _DELSIG8_1_StartAD
export  DELSIG8_1_StopAD
export _DELSIG8_1_StopAD

include "DELSIG8_1.inc"
include "m8c.inc"
;;------------------------------------------------------------------
;;  Start:
;;  SetPower:
;;  Applies power setting to the module's analog PSoc block.
;;  INPUTS:  A contains the power setting
;;  OUTPUTS: None.  
;;------------------------------------------------------------------
 DELSIG8_1_Start:
_DELSIG8_1_Start:
 DELSIG8_1_SetPower:
_DELSIG8_1_SetPower:
   push X            ;save X
   mov  X,SP	   ;X will point at next pushed value
   and  A,03h
   push A		   ;X points at copy of A
   mov  A,reg[DELSIG8_1_AtoDcr3]
   and  A,~03h       ;clear power bits
   or   A,[ X ]
   mov  reg[DELSIG8_1_AtoDcr3],A
   pop  A
   pop  X
   ret

;;------------------------------------------------------------------
;;  Stop:
;;  Removes power from the module's analog PSoc block.
;;  INPUTS:  None.
;;  OUTPUTS: None.  
;;------------------------------------------------------------------
 DELSIG8_1_Stop:
_DELSIG8_1_Stop:
   ;; Machine cycles required: Setup (?) + Call(11 or 13) + 13
   and reg[DELSIG8_1_AtoDcr3], ~03h
   ret

;;------------------------------------------------------------------
;;  StartAD:
;;  Starts the A/D convertor,  inttializes the data buuffer pointers,
;;  enables the integrator, and enables the timer so the A/D will
;;  operate.
;;  INPUTS:  None.
;;  OUTPUTS: None.  
;;------------------------------------------------------------------
 DELSIG8_1_StartAD:
_DELSIG8_1_StartAD:
   or  reg[INT_MSK1],DELSIG8_1_TimerMask
                                          ;Enable timer interrupt
   and reg[DELSIG8_1_AtoDcr3],~10h ;Enable the Integrator
IF DELSIG8_1_NoAZ
   and  reg[DELSIG8_1_AtoDcr2],~20h
ENDIF

   mov reg[DELSIG8_1_TimerDR1],FFh ;initialize Timer
   mov reg[DELSIG8_1_TimerCR0],01h ;enable the Timer
   ret

;;------------------------------------------------------------------
;;  StopAD:
;;  Completely shuts down the A/D is an orderly manner.  The
;;  Timer interrupt is disabled.
;;  INPUTS:  None.
;;  OUTPUTS: None.  
;;------------------------------------------------------------------
 DELSIG8_1_StopAD:
_DELSIG8_1_StopAD:
  ;Disable interrupt
   M8C_DisableIntMask INT_MSK1, DELSIG8_1_TimerMask 
   mov REG[DELSIG8_1_TimerCR0],00h       ;disable the Timer
IF DELSIG8_1_NoAZ
   or  reg[DELSIG8_1_AtoDcr2],20h        ;force the Integrator into reset
ENDIF
   or  REG[DELSIG8_1_AtoDcr3],10h        ;reset Integrator
   ret

DELSIG8_1_API_End:



