;;********************************************************************
;;********************************************************************
;;  DELSIG8int.asm
;;
;;  Assembler source for interrupt routines the 8 bit Delta Sigma
;;  A/D converter.
;;
;;  Rev B, 2002 JUL 25
;;
;;  Copyright: Cypress MicroSystems 2000,2001.  All Rights Reserved.
;;
;;*********************************************************************
;;*********************************************************************

export  DELSIG8_1_ADConversion
include "DELSIG8_1.inc"
include "m8c.inc"
include "TX8_1.inc"

TX_REG_COMPLETE: 	EQU 20h			;declare values for testing TX status byte
TX_REG_EMPTY: 		EQU 10h


area bss(RAM) 
   iOut:  BLK  2  ;the ADC
   iTmp2: BLK  2  ;z^-2
   iTmp1: BLK  2  ;z^-1
area text(ROM,REL)

COUNTER1: equ F0h
COUNTER2: equ F1h


;;------------------------------------------------------------------
;;  DELSIG8_1_ADConversion:
;;  This routine takes the data from the decimator and calculates
;;  a new 8 bit value.  A entry point in this API has been marked where the user
;;  get this data.
;;  INPUTS:  None.
;;  OUTPUTS: None.  
;;------------------------------------------------------------------
LowByte:   equ 1
HighByte:  equ 0
DELSIG8_1_ADConversion:
   push A
   ;Initial state
   ;Out  (x3-x2)-(x2-x1)
   ;Tmp2 (x2-x1) 
   ;Tmp1  x1         
   ;deci  x0

   mov [(iOut + LowByte)], [(iTmp2 + LowByte)] 
   mov [(iOut + HighByte)],[(iTmp2 + HighByte)]
   ;Tmp2 moved to Out
   ;Out  (x2-x1)
   ;Tmp2 (x2-x1) 
   ;Tmp1  x1         
   ;deci  x0
   
   mov [(iTmp2 + LowByte)], [(iTmp1 + LowByte)]
   mov [(iTmp2 + HighByte)],[(iTmp1 + HighByte)]
   ;Tmp1 moved to Tmp2
   ;Out  (x2-x1)
   ;Tmp2  x1 
   ;Tmp1  x1         
   ;deci  x0
  
   mov A,reg[DEC_DL]
   mov [(iTmp1 + LowByte)],A
   sub [(iTmp2 + LowByte)],A
   mov A,reg[DEC_DH]
   mov [(iTmp1 + HighByte)],A
   sbb [(iTmp2 + HighByte)],A
   ;Deci to Tmp1 & deci subtracted from Tmp2
   ;Out  (x2-x1)
   ;Tmp2  x1-x0 
   ;Tmp1  x0         
   ;deci  x0

   mov A,[(iTmp2 + LowByte)]
   sub [(iOut + LowByte)],A
   mov A,[(iTmp2 + HighByte)]
   sbb [(iOut + HighByte)],A
   ;Subtract Tmp2 for Out
   ;Out  (x2-x1)-(x1-x0)
   ;Tmp2  x1-x0 
   ;Tmp1  x0         
   ;deci  x0

    cmp [(iOut + HighByte)],10h
   jnz else2
;  if(value is full scale)
      mov A,7fh
      jmp endif2
   else2:;(value is less than full scale)
      mov A,[(iOut + HighByte)]
	rlc [(iOut + LowByte)]	; divide by 32 (multiply by 8)
	rlc A
	rlc [(iOut + LowByte)]
	rlc A
	rlc [(iOut + LowByte)]
	rlc A
   endif2:
;;--------------------------------------------------------
;;
;;  data is now in A.
;;  The user's handler should be placed here

inc [00]
CMP [00],F0h
JZ send
//MOV	[00],01h

mov X,[00]
mov [X],A
jmp end

send:
mov [00],00h
;push x
mov X,01h
WaitForTxStart:
	tst	  reg[TX8_1_CONTROL_REG],TX_REG_EMPTY
    jz     WaitForTxStart

mov A,[X]
call   TX8_1_SendData  
inc x
mov A,X
cmp A,F0h
jnz WaitForTxStart

;pop x
;;
;;-------------------------------------------------------- 
 end:
   pop A
   reti

DELAY:

	mov	A,80			;4 Cycle	(K)
	mov[COUNTER1],A		;5 Cycle
LOOP1:
	mov	A,50			;4 Cycle x K	(L)
	mov[COUNTER2],A		;5 Cycle x K
	
LOOP2:
	DEC [COUNTER2]		;7 Cycle x L x K
	JNZ	LOOP2			;(5 Cycle x (L-1) + 4) x K 
	
	DEC	[COUNTER1]		;7 Cycle x K
	JNZ	LOOP1			;5 Cycle x (K-1) + (4 Cycle)

	;TOTAL = 4 + 5 + 4K + 5K + 7LK + 5LK -5K + 4K +7K +5K -1
	;TOTAL = 12LK + 20K + 8
	
	
	ret


DELSIG8_1_APIINT_END:

