;;************************************************************************
;;************************************************************************
;;
;; SAR6_1.asm  (from SAR6.asm user module template)
;;
;;  Assembler Source for the 6-bit SAR user module API.
;;
;;  Rev A, 2002 Mar 30
;;
;;  Copyright (c) 2001-2002 Cypress Microsystems, Inc. All rights reserved.
;;
;;************************************************************************
;;************************************************************************

EXPORT  SAR6_1_Start
export _SAR6_1_Start
export  SAR6_1_SetPower
export _SAR6_1_SetPower
export  SAR6_1_GetSample
export _SAR6_1_GetSample
export  SAR6_1_Stop
export _SAR6_1_Stop

include "m8c.inc"
include "SAR6_1.inc"

bPWRMASK:  equ 03h              ; Power bitfield in Switched Cap CR3 reg

;;-------------------------------------------------------------------
;; Start & SetPower
;; ----------------
;; Applies power setting to the module's SoCblocs
;; INPUTS: A contains the power setting 0=Off, 1=Low, 2=Med, 3=High
;; OUTUTS: None
;;-------------------------------------------------------------------

 SAR6_1_Start:
_SAR6_1_Start:
    ;; Initialization-time only code goes here.

 SAR6_1_SetPower:
_SAR6_1_SetPower:

    and   A, bPWRMASK       ; trim to bits of interest
    mov   X, SP             ; Set stack frame pointer
    push  A

    ;; read CR3 register, modify power bits & write back
    mov   A, reg[SAR6_1_CR3]
    and   A, ~bPWRMASK      ; clear old setting
    or    A, [X]            ; set power in register image
    mov   reg[SAR6_1_CR3], A
    pop   A
    ret


;------------------------------------------------------------------------------
; GetSample
; ---------
; Utilize SAR acceleration hardware to guide a binary search
; until the output of the 6-bit DAC output is within 1 bit of the
; input voltage.
;
; INPUTS:  None
; RETURNS: 2's Complement Value in [-31..+31]
;------------------------------------------------------------------------------

PSOC_ANALOG_COL_MASK:  equ 0Ch ; mask for column bits in analog reg address
PSOC_SAR_CTRL:         equ 68h ;
PSOC_SAR_MAGNITUDE:    equ 1Fh ;
PSOC_SAR_SIGN:         equ 20h ;

 SAR6_1_GetSample:
_SAR6_1_GetSample:

    ;; Set up initial condition and SAR acceleration hardware.
    mov  reg[SAR6_1_CR0], SAR6_1_CR0_INIT
    mov  reg[ASY_CR], PSOC_SAR_CTRL | ((SAR6_1_CR0 & PSOC_ANALOG_COL_MASK)>>1)

    ;; Drive the binary search engine with read/modify/write instructions.
    ;; NOTE: each of the next 6 instructions stalls the CPU consuming one
    ;; complete analog column clock cycle (input clock divided by 4).
    or   reg[SAR6_1_CR0], 0   ; set sign & try MSB of magnitude
    or   reg[SAR6_1_CR0], 0   ; set MSB of magnitude and try next lower
    or   reg[SAR6_1_CR0], 0   ;                      ... and next ...
    or   reg[SAR6_1_CR0], 0   ;                      ... and next ...
    or   reg[SAR6_1_CR0], 0   ;                      ... and try LSB
    or   reg[SAR6_1_CR0], 0   ; and, finally, set LSB of magnitude.

    ;; Conversion is done, translate the result to 1-byte 2's complement form.
    ;; Negative and positive values are handled differently. To minimize
    ;; aperature jitter, the execution cycles consumed in each case have been
    ;; equalized. The cost of this is 13 cycles for positive values; 5 cycles
    ;; for negative values.
    mov  A, reg[SAR6_1_CR0]
    and  A, PSOC_SAR_MAGNITUDE
    tst  reg[SAR6_1_CR0], PSOC_SAR_SIGN
    jnz  GSNegative  ; Result is zero => sign was 1 (negative).
    nop              ; Delay to equalize number of required cycles.
    nop              ; Delay to equalize number of required cycles.
    ret
GSNegative:
    cpl  A           ; Take 2's complement of the magnitude
    inc  A           ;   to get its negative representation.
    ret


;;-------------------------------------------------------------------
;; Stop
;; ----
;; Cuts power to the user module.
;; INPUTS:  None
;; OUTPUTS: None
;;-------------------------------------------------------------------
 SAR6_1_Stop:
_SAR6_1_Stop:
    and reg[SAR6_1_CR3], ~bPWRMASK
    ret
